# Depscleaner

Depscleaner is a CLI tool for identifying and removing dependency directories like `node_modules` in your projects to free up space.

## Installation

Clone the repository and run:
```bash
python setup.py install
